@@ -1,4 +1,4 @@
-
+import collections
 from datetime import timedelta
 from datetime import datetime
 from functools import wraps
@@ -12,7 +12,7 @@ class InMemoryCacheManager(SignalBaseCacheManager):
 
     def __init__(self, options: DictEx) -> None:
         super().__init__(options)
-        self.__cache_list: 'dict[str, list[Callable]]' = dict()
+        self.__cache_list: 'dict[str, list[Callable]|any]' = dict()
 
     def cache_decorator(self, seconds: int = 0, key: str = None):
         """Cache result of function for seconds of time or until signal by key for clear"""
@@ -50,20 +50,36 @@ class InMemoryCacheManager(SignalBaseCacheManager):
         print(f"reset cache for {keys}")
         for key in keys:
             if key in self.__cache_list:
-                for function in self.__cache_list[key]:
-                    function.cache = None
+                if isinstance(self.__cache_list[key], collections.abc.Sequence):
+                    for function in self.__cache_list[key]:
+                        function.cache = None
+                else:
+                    self.__cache_list[key] = None
 
     def get_cache(self, key: str) -> list:
         """Get key related cached data"""
 
-        return [function.cache for function in self.__cache_list[key]] if key in self.__cache_list else None
+        return ([function.cache for function in self.__cache_list[key]]
+                if isinstance(self.__cache_list[key], collections.abc.Sequence)
+                else self.__cache_list[key]) if key in self.__cache_list else None
 
     def update_cache(self, key: str, data: any) -> bool:
         """Update key related cached data"""
 
-        is_siccessfull = False
+        is_successful = False
         if key in self.__cache_list:
-            for function in self.__cache_list[key]:
-                function.cache = data
-                is_siccessfull = True
-        return is_siccessfull
+            if isinstance(self.__cache_list[key], collections.abc.Sequence):
+                for function in self.__cache_list[key]:
+                    function.cache = data
+            else:
+                self.__cache_list[key] = data
+            is_successful = True
+        return is_successful
+
+    def add_or_update_cache(self, key: str, data: any) -> bool:
+        """Add or update key related cached data"""
+
+        is_successfully = self.update_cache(key, data)
+        if not is_successfully:
+            self.__cache_list[key] = data
+        return is_successfully
