@@ -3,5 +3,6 @@ from enum import Enum
 
 class MergeType(Enum):
     """enum of merge type"""
-    REPLACE = 0,
-    APPEND = 1,
+
+    REPLACE = 0
+    APPEND = 1
