@@ -3,3 +3,5 @@ from bclib.dispatcher.idispatcher import IDispatcher
 from bclib.dispatcher.socket_dispatcher import SocketDispatcher
 from bclib.dispatcher.dev_server_dispatcher import DevServerDispatcher
 from bclib.dispatcher.routing_dispatcher import RoutingDispatcher
+from bclib.dispatcher.named_pipe_dispatcher import NamedPipeDispatcher
+from bclib.dispatcher.endpoint_dispatcher import EndpointDispatcher
