@@ -1,4 +1,4 @@
-import threading
+import asyncio
 from ..dispatcher.routing_dispatcher import RoutingDispatcher
 from ..listener import Endpoint, Message, SocketListener
 
@@ -6,7 +6,7 @@ from ..listener import Endpoint, Message, SocketListener
 class SocketDispatcher(RoutingDispatcher):
     def __init__(self, options: dict):
         super().__init__(options)
-        self.__lock = threading.Lock()
+        self.__lock = asyncio.Lock()
         self.__listener = SocketListener(
             Endpoint(self.options.receiver),
             Endpoint(self.options.sender),
@@ -15,11 +15,8 @@ class SocketDispatcher(RoutingDispatcher):
     async def send_message_async(self, message: Message) -> bool:
         """Send message to endpoint"""
 
-        try:
-            self.__lock.acquire()
+        async with self.__lock:
             return await self.__listener.send_message_async(message)
-        finally:
-            self.__lock.release()
 
     def initialize_task(self):
         super().initialize_task()
