@@ -6,3 +6,5 @@ from bclib.listener.message_type import MessageType
 from bclib.listener.http_listener.http_listener import HttpListener
 from bclib.listener.http_listener.http_base_data_name import HttpBaseDataName
 from bclib.listener.http_listener.http_base_data_type import HttpBaseDataType
+from bclib.listener.windows_named_pipe_listener import WindowsNamedPipeListener
+from bclib.listener.linux_named_pipe_listener import LinuxNamedPipeListener
