@@ -22,7 +22,8 @@ class RabbitBusListener(RabbitListener):
             }
             new_context = RabbitContext(
                 DictEx(message), self.__dispatcher)
-            self.__dispatcher.dispatch_async(new_context)
+            self.__dispatcher.dispatch_in_background(new_context)
+            print(f"Message '{message}' received to rabbit listener")
         except error as ex:
             print(
                 f"error in dispatcher received message from rabbit in {self._host}:{self._queue_name} ({ex})")
