@@ -41,7 +41,6 @@ class Answer:
                                         values["answer"]) if 'answer' in values.keys() else None
                                     self.__answer_list.append(UserAction(
                                         prp_id, action_type, prp_value_id, internal_prp_value_id, value_id, value, None, multi, part_number, answer))
-
                         else:
                             internal_prp_value_id = internal_prp_value_index
                             prp_id = data['propId']
@@ -52,23 +51,28 @@ class Answer:
                         internal_prp_value_index += 1
         await self.__try_set_data_type_async()
 
-    async def __get_action_async(self, prp_id_list: 'list[int]', action_list: 'list[UserActionTypes]', part_list: 'list[int]', predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
+    async def __get_action_async(self, prp_id_list: 'list[int]', action_list: 'list[UserActionTypes]', part_list: 'list[int]', is_file: "bool" = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
         ret_val: 'list[UserAction]' = None
         if self.__answer_list is None:
             await self.__fill_answer_list_async()
         if predicate:
-            ret_val = [x for x in self.__answer_list if predicate(x)]
+            if is_file == None:
+                ret_val = [x for x in self.__answer_list if predicate(x)]
+            else:
+                ret_val = [x for x in self.__answer_list if predicate(
+                    x) and x.is_file_content() == is_file]
         else:
             ret_val = [x for x in self.__answer_list if
                        (prp_id_list is None or x.prp_id in prp_id_list) and
                        (action_list is None or x.action in action_list) and
-                       (part_list is None or x.part in part_list)
+                       (part_list is None or x.part in part_list) and
+                       (is_file is None or x.is_file_content() == is_file)
                        ]
 
         return ret_val if ret_val else list()
 
     async def get_actions_async(self, prp_id: 'int|list[int]' = None, action: 'UserActionTypes|list[UserActionTypes]' = None,
-                                part: int = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
+                                part: int = None, is_file: "bool" = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
         """
         inputs:
         prpid: None, int or list[int]
@@ -83,11 +87,13 @@ class Answer:
             action, UserActionTypes) else action
         prp_id_list = [prp_id] if isinstance(prp_id, int) else prp_id
         part_list = [part] if isinstance(part, int) else part
-        return await self.__get_action_async(prp_id_list, action_list, part_list, predicate)
+        return await self.__get_action_async(prp_id_list, action_list, part_list, is_file, predicate)
 
-    def __data_type_checker(self, view_type: str, datatype: str = None):
+    def __data_type_checker(self, view_type: str, datatype: str = None, has_link: bool = None):
 
-        if view_type in ["select", "checkList"]:
+        if view_type in ["select", "checkList", "radio"]:
+            if has_link == True:
+                result = "urlvalues"
             result = "fixvalue"
         elif view_type == "textarea":
             result = "ntextvalue"
@@ -98,7 +104,9 @@ class Answer:
         elif view_type == "text" and datatype == "float":
             result = "floatvalue"
         elif view_type == "autocomplete":
-            result = "autocomplete"
+            result = "urlvalue"
+        elif view_type == "upload":
+            result == "files"
         else:
             result = "None"
         return result
@@ -111,25 +119,26 @@ class Answer:
                 for question in data.data:
                     for parts in question.questions:
                         for validations in parts.parts:
+                            has_link = True if validations.link else False
                             data_type = validations.validations["datatype"] if "datatype" in validations.validations.keys(
                             ) else "None"
                             type_list.append({
                                 "prpId": parts.prpId, "part": validations.part, "viewtype": validations.viewType,
-                                "datatype": data_type, "table": self.__data_type_checker(validations.viewType, data_type)
+                                "datatype": data_type, "table": self.__data_type_checker(validations.viewType, data_type, has_link)
                             })
             for type in type_list:
                 for values in self.__answer_list:
                     if int(type['prpId']) == int(values.prp_id) and type["part"] == values.part or values.part is None:
                         values.datatype = type['table']
 
-    async def get_added_actions_async(self, prp_id: 'int|list[int]' = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
+    async def get_added_actions_async(self, prp_id: 'int|list[int]' = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[list[list[UserAction]]]':
         return await self.__get_specify_actions(UserActionTypes.ADDED, prp_id, predicate)
-    
-    async def get_edited_actions_async(self, prp_id: 'int|list[int]' = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
+
+    async def get_edited_actions_async(self, prp_id: 'int|list[int]' = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[list[list[UserAction]]]':
         return await self.__get_specify_actions(UserActionTypes.EDITED, prp_id, predicate)
 
-    async def __get_specify_actions(self, action_type:UserActionTypes, prp_id: 'int|list[int]' = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[UserAction]':
-        ret_val: 'dict[int:"list[list[UserAction]]"]' = {}
+    async def __get_specify_actions(self, action_type: UserActionTypes, prp_id: 'int|list[int]' = None, predicate: 'Callable[[UserAction],bool]' = None) -> 'list[list[list[UserAction]]]':
+        ret_val: "dict[int,list[list[UserAction]]]" = {}
         action_objects = await self.get_actions_async(prp_id=prp_id, action=action_type, predicate=predicate)
         unique_internal_values_id = set(
             [obj.internal_prp_value_id for obj in action_objects])
